@@ -19,6 +19,8 @@ from mypy_boto3_devops_guru.literals import (
     AnomalySeverity,
     AnomalyStatus,
     CloudWatchMetricsStat,
+    CostEstimationServiceResourceState,
+    CostEstimationStatus,
     EventClass,
     EventDataSource,
     InsightFeedbackOption,
@@ -26,6 +28,7 @@ from mypy_boto3_devops_guru.literals import (
     InsightStatus,
     InsightType,
     OptInStatus,
+    ServiceName,
 )
 
 if sys.version_info >= (3, 8):
@@ -40,9 +43,12 @@ __all__ = (
     "AnomalyTimeRangeTypeDef",
     "CloudFormationCollectionFilterTypeDef",
     "CloudFormationCollectionTypeDef",
+    "CloudFormationCostEstimationResourceCollectionFilterTypeDef",
     "CloudFormationHealthTypeDef",
     "CloudWatchMetricsDetailTypeDef",
     "CloudWatchMetricsDimensionTypeDef",
+    "CostEstimationResourceCollectionFilterTypeDef",
+    "CostEstimationTimeRangeTypeDef",
     "DescribeAccountHealthResponseTypeDef",
     "DescribeAccountOverviewResponseTypeDef",
     "DescribeAnomalyResponseTypeDef",
@@ -54,6 +60,7 @@ __all__ = (
     "EventResourceTypeDef",
     "EventTimeRangeTypeDef",
     "EventTypeDef",
+    "GetCostEstimationResponseTypeDef",
     "GetResourceCollectionResponseTypeDef",
     "InsightFeedbackTypeDef",
     "InsightHealthTypeDef",
@@ -93,7 +100,11 @@ __all__ = (
     "ResourceCollectionTypeDef",
     "SearchInsightsFiltersTypeDef",
     "SearchInsightsResponseTypeDef",
+    "ServiceCollectionTypeDef",
+    "ServiceHealthTypeDef",
+    "ServiceInsightHealthTypeDef",
     "ServiceIntegrationConfigTypeDef",
+    "ServiceResourceCostTypeDef",
     "SnsChannelConfigTypeDef",
     "StartTimeRangeTypeDef",
     "UpdateCloudFormationCollectionFilterTypeDef",
@@ -126,6 +137,10 @@ class CloudFormationCollectionTypeDef(TypedDict, total=False):
     StackNames: List[str]
 
 
+class CloudFormationCostEstimationResourceCollectionFilterTypeDef(TypedDict, total=False):
+    StackNames: List[str]
+
+
 class CloudFormationHealthTypeDef(TypedDict, total=False):
     StackName: str
     Insight: "InsightHealthTypeDef"
@@ -145,6 +160,15 @@ class CloudWatchMetricsDimensionTypeDef(TypedDict, total=False):
     Value: str
 
 
+class CostEstimationResourceCollectionFilterTypeDef(TypedDict, total=False):
+    CloudFormation: "CloudFormationCostEstimationResourceCollectionFilterTypeDef"
+
+
+class CostEstimationTimeRangeTypeDef(TypedDict, total=False):
+    StartTime: datetime
+    EndTime: datetime
+
+
 class DescribeAccountHealthResponseTypeDef(TypedDict):
     OpenReactiveInsights: int
     OpenProactiveInsights: int
@@ -179,6 +203,7 @@ class _RequiredDescribeResourceCollectionHealthResponseTypeDef(TypedDict):
 class DescribeResourceCollectionHealthResponseTypeDef(
     _RequiredDescribeResourceCollectionHealthResponseTypeDef, total=False
 ):
+    Service: List["ServiceHealthTypeDef"]
     NextToken: str
 
 
@@ -212,6 +237,15 @@ class EventTypeDef(TypedDict, total=False):
     Resources: List["EventResourceTypeDef"]
 
 
+class GetCostEstimationResponseTypeDef(TypedDict, total=False):
+    ResourceCollection: "CostEstimationResourceCollectionFilterTypeDef"
+    Status: CostEstimationStatus
+    Costs: List["ServiceResourceCostTypeDef"]
+    TimeRange: "CostEstimationTimeRangeTypeDef"
+    TotalCost: float
+    NextToken: str
+
+
 class GetResourceCollectionResponseTypeDef(TypedDict, total=False):
     ResourceCollection: "ResourceCollectionFilterTypeDef"
     NextToken: str
@@ -366,6 +400,7 @@ class ProactiveInsightSummaryTypeDef(TypedDict, total=False):
     InsightTimeRange: "InsightTimeRangeTypeDef"
     PredictionTimeRange: "PredictionTimeRangeTypeDef"
     ResourceCollection: "ResourceCollectionTypeDef"
+    ServiceCollection: "ServiceCollectionTypeDef"
 
 
 class ProactiveInsightTypeDef(TypedDict, total=False):
@@ -406,6 +441,7 @@ class ReactiveInsightSummaryTypeDef(TypedDict, total=False):
     Status: InsightStatus
     InsightTimeRange: "InsightTimeRangeTypeDef"
     ResourceCollection: "ResourceCollectionTypeDef"
+    ServiceCollection: "ServiceCollectionTypeDef"
 
 
 class ReactiveInsightTypeDef(TypedDict, total=False):
@@ -468,6 +504,7 @@ class SearchInsightsFiltersTypeDef(TypedDict, total=False):
     Severities: List[InsightSeverity]
     Statuses: List[InsightStatus]
     ResourceCollection: "ResourceCollectionTypeDef"
+    ServiceCollection: "ServiceCollectionTypeDef"
 
 
 class SearchInsightsResponseTypeDef(TypedDict, total=False):
@@ -476,10 +513,37 @@ class SearchInsightsResponseTypeDef(TypedDict, total=False):
     NextToken: str
 
 
+class ServiceCollectionTypeDef(TypedDict, total=False):
+    ServiceNames: List[ServiceName]
+
+
+class ServiceHealthTypeDef(TypedDict, total=False):
+    ServiceName: ServiceName
+    Insight: "ServiceInsightHealthTypeDef"
+
+
+class ServiceInsightHealthTypeDef(TypedDict, total=False):
+    OpenProactiveInsights: int
+    OpenReactiveInsights: int
+
+
 class ServiceIntegrationConfigTypeDef(TypedDict, total=False):
     OpsCenter: "OpsCenterIntegrationTypeDef"
 
 
+ServiceResourceCostTypeDef = TypedDict(
+    "ServiceResourceCostTypeDef",
+    {
+        "Type": str,
+        "State": CostEstimationServiceResourceState,
+        "Count": int,
+        "UnitCost": float,
+        "Cost": float,
+    },
+    total=False,
+)
+
+
 class SnsChannelConfigTypeDef(TypedDict, total=False):
     TopicArn: str
 
